@@ -31,6 +31,7 @@ from snowflake.snowpark._internal.analyzer.analyzer_utils import (
     specified_window_frame_expression,
     subfield_expression,
     subquery_expression,
+    table_function_partition_spec,
     unary_expression,
     update_merge_statement,
     values_statement,
@@ -93,9 +94,10 @@ from snowflake.snowpark._internal.analyzer.table_function import (
     FlattenFunction,
     Lateral,
     NamedArgumentsTableFunction,
-    TableFunction,
+    PosArgumentsTableFunction,
     TableFunctionExpression,
     TableFunctionJoin,
+    TableFunctionPartitionSpecDefinition,
     TableFunctionRelation,
 )
 from snowflake.snowpark._internal.analyzer.table_merge_expression import (
@@ -250,6 +252,15 @@ class Analyzer:
         if isinstance(expr, TableFunctionExpression):
             return self.table_function_expression_extractor(expr)
 
+        if isinstance(expr, TableFunctionPartitionSpecDefinition):
+            return table_function_partition_spec(
+                expr.over,
+                list(map(self.analyze, expr.partition_spec))
+                if expr.partition_spec
+                else [],
+                list(map(self.analyze, expr.order_spec)) if expr.order_spec else [],
+            )
+
         if isinstance(expr, UnaryExpression):
             return self.unary_expression_extractor(expr)
 
@@ -315,17 +326,23 @@ class Analyzer:
                 expr.recursive,
                 expr.mode,
             )
-
-        if isinstance(expr, TableFunction):
-            return function_expression(
+        elif isinstance(expr, PosArgumentsTableFunction):
+            sql = function_expression(
                 expr.func_name, [self.analyze(x) for x in expr.args], False
             )
-
-        if isinstance(expr, NamedArgumentsTableFunction):
-            return named_arguments_function(
+        elif isinstance(expr, NamedArgumentsTableFunction):
+            sql = named_arguments_function(
                 expr.func_name,
                 {key: self.analyze(value) for key, value in expr.args.items()},
             )
+        else:
+            raise TypeError(
+                "A table function expression should be any of PosArgumentsTableFunction, NamedArgumentsTableFunction, or FlattenFunction."
+            )
+        partition_spec_sql = (
+            self.analyze(expr.partition_spec) if expr.partition_spec else ""
+        )
+        return f"{sql} {partition_spec_sql}"
 
     def unary_expression_extractor(self, expr: UnaryExpression) -> str:
         if isinstance(expr, Alias):
@@ -370,7 +387,7 @@ class Analyzer:
         try:
             num = int(offset)
             return window_frame_boundary_expression(str(abs(num)), num >= 0)
-        except:
+        except Exception:
             return offset
 
     def to_sql_avoid_offset(self, expr: Expression) -> str:
@@ -401,13 +418,13 @@ class Analyzer:
         use_maps = {}
         # get counts of expr_to_alias keys
         counts = Counter()
-        for k, v in resolved_children.items():
+        for v in resolved_children.values():
             if v.expr_to_alias:
                 counts.update(list(v.expr_to_alias.keys()))
 
         # Keep only non-shared expr_to_alias keys
         # let (df1.join(df2)).join(df2.join(df3)).select(df2) report error
-        for k, v in resolved_children.items():
+        for v in resolved_children.values():
             if v.expr_to_alias:
                 use_maps.update(
                     {p: q for p, q in v.expr_to_alias.items() if counts[p] < 2}
@@ -499,7 +516,6 @@ class Analyzer:
             )
 
         if isinstance(logical_plan, Range):
-            # The column name id lower-case is hard-coded by Spark as the output
             # schema of Range. Since this corresponds to the Snowflake column "id"
             # (quoted lower-case) it's a little hard for users. So we switch it to
             # the column name "ID" == id == Id
@@ -612,6 +628,7 @@ class Analyzer:
                     if logical_plan.transformations
                     else None,
                     user_schema=logical_plan.user_schema,
+                    create_table_from_infer_schema=logical_plan.create_table_from_infer_schema,
                 )
             elif logical_plan.file_format and logical_plan.file_format.upper() == "CSV":
                 if not logical_plan.user_schema:
@@ -625,12 +642,17 @@ class Analyzer:
                         logical_plan.user_schema._to_attributes(),
                     )
             else:
+                schema = (
+                    logical_plan.user_schema._to_attributes()
+                    if logical_plan.user_schema
+                    else [Attribute('"$1"', VariantType())]
+                )
                 return self.plan_builder.read_file(
                     logical_plan.files,
                     logical_plan.file_format,
                     logical_plan.cur_options,
                     self.session.get_fully_qualified_current_schema(),
-                    [Attribute('"$1"', VariantType())],
+                    schema,
                 )
 
         if isinstance(logical_plan, CopyIntoLocationNode):
