@@ -1,11 +1,6 @@
 #
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
-# Code in this file may constitute partial or total reimplementation, or modification of
-# existing code originally distributed by the Apache Software Foundation as part of the
-# Apache Spark project, under the Apache License, Version 2.0.
-#
-#  File containing the Expression definitions for ASTs (Spark).
 import uuid
 from typing import TYPE_CHECKING, Any, List, Optional, Tuple
 
@@ -47,8 +42,7 @@ class Expression:
 
     @property
     def sql(self) -> str:
-        """TODO: analyzer_object.py's analyze() method doesn't use this method to create sql statement.
-        The only place that uses Expression.sql() to generate sql statement
+        """The only place that uses Expression.sql() to generate sql statement
         is relational_grouped_dataframe.py's __toDF(). Re-consider whether we need to make the sql generation
         consistent among all different Expressions.
         """
@@ -57,7 +51,7 @@ class Expression:
         )
         return f"{self.pretty_name}({children_sql})"
 
-    def __repr__(self) -> str:
+    def __str__(self) -> str:
         return self.pretty_name
 
 
