@@ -3,6 +3,7 @@
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
 import re
+import sys
 import uuid
 from functools import cached_property, reduce
 from typing import Any, Callable, Dict, List, Optional, Tuple
@@ -25,7 +26,6 @@ from snowflake.snowpark._internal.analyzer.analyzer_utils import (
     drop_table_if_exists_statement,
     file_operation_statement,
     filter_statement,
-    infer_schema_statement,
     insert_into_statement,
     join_statement,
     join_table_function_statement,
@@ -34,7 +34,6 @@ from snowflake.snowpark._internal.analyzer.analyzer_utils import (
     merge_statement,
     pivot_statement,
     project_statement,
-    quote_name_without_upper_casing,
     result_scan_statement,
     sample_statement,
     schema_cast_named,
@@ -58,7 +57,6 @@ from snowflake.snowpark._internal.analyzer.snowflake_plan_node import (
     SaveMode,
 )
 from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
-from snowflake.snowpark._internal.type_utils import convert_sf_to_sp_type
 from snowflake.snowpark._internal.utils import (
     COPY_OPTIONS,
     INFER_SCHEMA_FORMAT_TYPES,
@@ -83,8 +81,12 @@ class SnowflakePlan(LogicalPlan):
                 try:
                     return func(*args, **kwargs)
                 except snowflake.connector.errors.ProgrammingError as e:
+                    tb = sys.exc_info()[2]
                     if "unexpected 'as'" in e.msg.lower():
-                        raise SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_UNEXPECTED_ALIAS() from e
+                        ne = (
+                            SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_UNEXPECTED_ALIAS()
+                        )
+                        raise ne.with_traceback(tb) from None
                     elif e.sqlstate == "42000" and "invalid identifier" in e.msg:
                         match = (
                             SnowflakePlan.Decorator.__wrap_exception_regex_match.match(
@@ -92,7 +94,10 @@ class SnowflakePlan(LogicalPlan):
                             )
                         )
                         if not match:
-                            raise e
+                            ne = SnowparkClientExceptionMessages.SQL_EXCEPTION_FROM_PROGRAMMING_ERROR(
+                                e
+                            )
+                            raise ne.with_traceback(tb) from None
                         col = match.group(1)
                         children = [
                             arg for arg in args if isinstance(arg, SnowflakePlan)
@@ -111,9 +116,10 @@ class SnowflakePlan(LogicalPlan):
                             orig_col_name = (
                                 unaliased_cols[0] if unaliased_cols else "<colname>"
                             )
-                            raise SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_INVALID_ID(
+                            ne = SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_INVALID_ID(
                                 orig_col_name
-                            ) from e
+                            )
+                            raise ne.with_traceback(tb) from None
                         elif (
                             len(
                                 [
@@ -127,13 +133,20 @@ class SnowflakePlan(LogicalPlan):
                             )
                             > 1
                         ):
-                            raise SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_JOIN_AMBIGUOUS(
+                            ne = SnowparkClientExceptionMessages.SQL_PYTHON_REPORT_JOIN_AMBIGUOUS(
                                 col, col
-                            ) from e
+                            )
+                            raise ne.with_traceback(tb) from None
                         else:
-                            raise e
+                            ne = SnowparkClientExceptionMessages.SQL_EXCEPTION_FROM_PROGRAMMING_ERROR(
+                                e
+                            )
+                            raise ne.with_traceback(tb) from None
                     else:
-                        raise e
+                        ne = SnowparkClientExceptionMessages.SQL_EXCEPTION_FROM_PROGRAMMING_ERROR(
+                            e
+                        )
+                        raise ne.with_traceback(tb) from None
 
             return wrap
 
@@ -437,8 +450,9 @@ class SnowflakePlanBuilder:
     def union(
         self, children: List[SnowflakePlan], source_plan: Optional[LogicalPlan]
     ) -> SnowflakePlan:
-        func = lambda x, y: self.set_operator(x, y, "UNION ALL ", source_plan)
-        return reduce(func, children)
+        return reduce(
+            lambda x, y: self.set_operator(x, y, "UNION ALL ", source_plan), children
+        )
 
     def join(
         self,
@@ -740,6 +754,7 @@ class SnowflakePlanBuilder:
         column_names: Optional[List[str]] = None,
         transformations: Optional[List[str]] = None,
         user_schema: Optional[StructType] = None,
+        create_table_from_infer_schema: bool = False,
     ) -> SnowflakePlan:
         # tracking usage of pattern, will refactor this function in future
         if pattern:
@@ -759,7 +774,13 @@ class SnowflakePlanBuilder:
         )
         if self.session._table_exists(table_name):
             queries = [Query(copy_command)]
-        elif user_schema and not transformations:
+        elif user_schema and (
+            (file_format.upper() == "CSV" and not transformations)
+            or (
+                create_table_from_infer_schema
+                and file_format.upper() in INFER_SCHEMA_FORMAT_TYPES
+            )
+        ):
             attributes = user_schema._to_attributes()
             queries = [
                 Query(
