@@ -11,11 +11,14 @@ import datetime
 import decimal
 import re
 import sys
-import typing  # type: ignore
+import typing  # noqa: F401
 from array import array
-from typing import (
+from typing import (  # noqa: F401
     Any,
     Dict,
+    Generator,
+    Iterable,
+    Iterator,
     List,
     NewType,
     Optional,
@@ -154,15 +157,10 @@ def convert_sp_to_sf_type(datatype: DataType) -> str:
         return "VARIANT"
     if isinstance(datatype, GeographyType):
         return "GEOGRAPHY"
-    raise TypeError(f"Unsupported data type: {datatype.type_name}")
+    raise TypeError(f"Unsupported data type: {datatype.__class__.__name__}")
 
 
-# #####################################################################################
-# Converting python types to types
-# Taken as is or modified from:
-# https://spark.apache.org/docs/3.1.1/api/python/_modules/pyspark/sql/types.html
-
-# Mapping Python types to Spark SQL DataType
+# Mapping Python types to DataType
 NoneType = type(None)
 PYTHON_TO_SNOW_TYPE_MAPPINGS = {
     NoneType: NullType,
@@ -185,7 +183,7 @@ VALID_SNOWPARK_TYPES_FOR_LITERAL_VALUE = (
     _NumericType,
 )
 
-# Mapping Python array types to Spark SQL DataType
+# Mapping Python array types to DataType
 ARRAY_SIGNED_INT_TYPECODE_CTYPE_MAPPINGS = {
     "b": ctypes.c_byte,
     "h": ctypes.c_short,
@@ -313,20 +311,16 @@ def infer_schema(
 
 
 def merge_type(a: DataType, b: DataType, name: Optional[str] = None) -> DataType:
-    if name is None:
-        new_msg = lambda msg: msg
-        new_name = lambda n: "field %s" % n
-    else:
-        new_msg = lambda msg: f"{name}: {msg}"
-        new_name = lambda n: f"field {n} in {name}"
-
     # null type
     if isinstance(a, NullType):
         return b
     elif isinstance(b, NullType):
         return a
     elif type(a) is not type(b):
-        raise TypeError(new_msg(f"Cannot merge type {type(a)} and {type(b)}"))
+        err_msg = f"Cannot merge type {type(a)} and {type(b)}"
+        if name:
+            err_msg = f"{name}: {err_msg}"
+        raise TypeError(err_msg)
 
     # same type
     if isinstance(a, StructType):
@@ -335,7 +329,9 @@ def merge_type(a: DataType, b: DataType, name: Optional[str] = None) -> DataType
             StructField(
                 f.name,
                 merge_type(
-                    f.datatype, nfs.get(f.name, NullType()), name=new_name(f.name)
+                    f.datatype,
+                    nfs.get(f.name, NullType()),
+                    name=f"field {f.name} in {name}" if name else f"field {f.name}",
                 ),
             )
             for f in a.fields
@@ -456,8 +452,11 @@ def python_type_to_snow_type(tp: Union[str, Type]) -> Tuple[DataType, bool]:
 
 
 def retrieve_func_type_hints_from_source(
-    file_path: str, func_name: str, _source: Optional[str] = None
-) -> Dict[str, Type]:
+    file_path: str,
+    func_name: str,
+    class_name: Optional[str] = None,
+    _source: Optional[str] = None,
+) -> Dict[str, str]:
     """
     Retrieve type hints of a function from a source file, or a source string (test only).
     """
@@ -477,7 +476,7 @@ def retrieve_func_type_hints_from_source(
             return annotation.id
         raise TypeError(f"invalid type annotation: {annotation}")
 
-    class NodeVisitor(ast.NodeVisitor):
+    class FuncNodeVisitor(ast.NodeVisitor):
         type_hints = {}
         func_exist = False
 
@@ -494,10 +493,29 @@ def retrieve_func_type_hints_from_source(
         with open(file_path) as f:
             _source = f.read()
 
-    visitor = NodeVisitor()
-    visitor.visit(ast.parse(_source))
+    if class_name:
+
+        class ClassNodeVisitor(ast.NodeVisitor):
+            class_node = None
+
+            def visit_ClassDef(self, node):
+                if node.name == class_name:
+                    self.class_node = node
+
+        class_visitor = ClassNodeVisitor()
+        class_visitor.visit(ast.parse(_source))
+        if class_visitor.class_node is None:
+            raise ValueError(f"class {class_name} is not found in file {file_path}")
+        to_visit_node_for_func = class_visitor.class_node
+    else:
+        to_visit_node_for_func = ast.parse(_source)
+
+    visitor = FuncNodeVisitor()
+    visitor.visit(to_visit_node_for_func)
     if not visitor.func_exist:
-        raise ValueError(f"function {func_name} is not found in file {file_path}")
+        raise ValueError(
+            f"function {class_name if class_name else ''}{'.' if class_name else ''}{func_name} is not found in file {file_path}"
+        )
     return visitor.type_hints
 
 
