@@ -36,15 +36,15 @@ STAGE_PREFIX = "@"
 QUERY_TAG_TRACEBACK_LIMIT = 3
 
 # https://docs.snowflake.com/en/sql-reference/identifiers-syntax.html
-SNOWFLAKE_UNQUOTED_ID_PATTERN = r"([a-zA-Z_][\w\$]*)"
-SNOWFLAKE_QUOTED_ID_PATTERN = '("([^"]|"")+")'
+SNOWFLAKE_UNQUOTED_ID_PATTERN = r"([a-zA-Z_][\w\$]{0,255})"
+SNOWFLAKE_QUOTED_ID_PATTERN = '("([^"]|""){1,255}")'
 SNOWFLAKE_ID_PATTERN = (
     f"({SNOWFLAKE_UNQUOTED_ID_PATTERN}|{SNOWFLAKE_QUOTED_ID_PATTERN})"
 )
 
 # Valid name can be:
-#   identifier,
-#   identifier.identifier,
+#   identifier
+#   identifier.identifier
 #   identifier.identifier.identifier
 #   identifier..identifier
 SNOWFLAKE_OBJECT_RE_PATTERN = re.compile(
@@ -120,6 +120,7 @@ class TempObjectType(Enum):
     QUERY_TAG = "QUERY_TAG"
     COLUMN = "COLUMN"
     PROCEDURE = "PROCEDURE"
+    TABLE_FUNCTION = "TABLE_FUNCTION"
 
 
 def validate_object_name(name: str):
@@ -359,7 +360,7 @@ def calculate_checksum(
 def str_to_enum(value: str, enum_class: Type[Enum], except_str: str) -> Enum:
     try:
         return enum_class(value)
-    except:
+    except ValueError:
         raise ValueError(
             f"{except_str} must be one of {', '.join([e.value for e in enum_class])}"
         )
