@@ -5,7 +5,6 @@
 import re
 from typing import Callable, List, Tuple, Union
 
-import snowflake.snowpark  # type: ignore
 from snowflake.snowpark import functions
 from snowflake.snowpark._internal.analyzer.expression import (
     Expression,
@@ -51,13 +50,13 @@ def _alias(expr: Expression) -> NamedExpression:
 def _expr_to_func(expr: str, input_expr: Expression) -> Expression:
     lowered = expr.lower()
     if lowered in ["avg", "average", "mean"]:
-        return functions.avg(Column(input_expr)).expression
+        return functions.avg(Column(input_expr))._expression
     elif lowered in ["stddev", "std"]:
-        return functions.stddev(Column(input_expr)).expression
+        return functions.stddev(Column(input_expr))._expression
     elif lowered in ["count", "size"]:
-        return functions.count(Column(input_expr)).expression
+        return functions.count(Column(input_expr))._expression
     else:
-        return functions.builtin(lowered)(input_expr).expression
+        return functions.builtin(lowered)(input_expr)._expression
 
 
 def _str_to_expr(expr: str) -> Callable:
@@ -82,7 +81,7 @@ class _RollupType(_GroupType):
 
 
 class _PivotType(_GroupType):
-    def __init__(self, pivot_col: Expression, values: List[Expression]):
+    def __init__(self, pivot_col: Expression, values: List[Expression]) -> None:
         self.pivot_col = pivot_col
         self.values = values
 
@@ -104,13 +103,13 @@ class GroupingSets:
     =============================================================  ==================================
     """
 
-    def __init__(self, *sets: Union[Column, List[Column]]):
+    def __init__(self, *sets: Union[Column, List[Column]]) -> None:
         prepared_sets = parse_positional_args_to_list(*sets)
         prepared_sets = (
             prepared_sets if isinstance(prepared_sets[0], list) else [prepared_sets]
         )
         self._to_expression = GroupingSetsExpression(
-            [[c.expression for c in s] for s in prepared_sets]
+            [[c._expression for c in s] for s in prepared_sets]
         )
 
 
@@ -121,7 +120,7 @@ class RelationalGroupedDataFrame:
 
     def __init__(
         self, df: DataFrame, grouping_exprs: List[Expression], group_type: _GroupType
-    ):
+    ) -> None:
         self._df = df
         self._grouping_exprs = grouping_exprs
         self._group_type = group_type
@@ -202,13 +201,13 @@ class RelationalGroupedDataFrame:
         agg_exprs = []
         for e in exprs:
             if isinstance(e, Column):
-                agg_exprs.append(e.expression)
+                agg_exprs.append(e._expression)
             elif (
                 isinstance(e, tuple)
                 and isinstance(e[0], Column)
                 and isinstance(e[1], str)
             ):
-                agg_exprs.append(_str_to_expr(e[1])(e[0].expression))
+                agg_exprs.append(_str_to_expr(e[1])(e[0]._expression))
             else:
                 raise TypeError("Invalid input types for agg()")
 
@@ -241,7 +240,7 @@ class RelationalGroupedDataFrame:
         return self._to_df(
             [
                 Alias(
-                    functions.builtin("count")(Literal(1)).expression,
+                    functions.builtin("count")(Literal(1))._expression,
                     "count",
                 )
             ]
@@ -257,8 +256,8 @@ class RelationalGroupedDataFrame:
     def _builtin_internal(self, agg_name: str, *cols: ColumnOrName) -> DataFrame:
         agg_exprs = []
         for c in cols:
-            c_expr = Column(c).expression if isinstance(c, str) else c.expression
-            expr = functions.builtin(agg_name)(c_expr).expression
+            c_expr = Column(c)._expression if isinstance(c, str) else c._expression
+            expr = functions.builtin(agg_name)(c_expr)._expression
             agg_exprs.append(expr)
         return self._to_df(agg_exprs)
 
