@@ -17,7 +17,6 @@ from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
 import cloudpickle
 import pkg_resources
 
-import snowflake.snowpark  # type: ignore
 from snowflake.connector import ProgrammingError, SnowflakeConnection
 from snowflake.connector.options import installed_pandas, pandas
 from snowflake.connector.pandas_tools import write_pandas
@@ -36,7 +35,6 @@ from snowflake.snowpark._internal.analyzer.snowflake_plan_node import (
 from snowflake.snowpark._internal.analyzer.table_function import (
     FlattenFunction,
     TableFunctionRelation,
-    create_table_function_expression,
 )
 from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
 from snowflake.snowpark._internal.server_connection import ServerConnection
@@ -52,6 +50,7 @@ from snowflake.snowpark._internal.utils import (
     PythonObjJSONEncoder,
     TempObjectType,
     calculate_checksum,
+    deprecate,
     get_connector_version,
     get_os_name,
     get_python_version,
@@ -86,6 +85,10 @@ from snowflake.snowpark.query_history import QueryHistory
 from snowflake.snowpark.row import Row
 from snowflake.snowpark.stored_procedure import StoredProcedureRegistration
 from snowflake.snowpark.table import Table
+from snowflake.snowpark.table_function import (
+    TableFunctionCall,
+    _create_table_function_expression,
+)
 from snowflake.snowpark.types import (
     ArrayType,
     DateType,
@@ -100,8 +103,9 @@ from snowflake.snowpark.types import (
     _AtomicType,
 )
 from snowflake.snowpark.udf import UDFRegistration
+from snowflake.snowpark.udtf import UDTFRegistration
 
-logger = getLogger(__name__)
+_logger = getLogger(__name__)
 
 _session_management_lock = RLock()
 _active_sessions: Set["Session"] = set()
@@ -153,8 +157,8 @@ class Session:
         ... }
         >>> session = Session.builder.configs(connection_parameters).create() # doctest: +SKIP
 
-    :class:`Session` contains functions to construct a :class:`DataFrame` like :func:`table`,
-    :func:`sql` and :func:`read`.
+    :class:`Session` contains functions to construct a :class:`DataFrame` like :meth:`table`,
+    :meth:`sql` and :attr:`read`.
 
     A :class:`Session` object is not thread-safe.
     """
@@ -164,7 +168,7 @@ class Session:
         Provides methods to set connection parameters and create a :class:`Session`.
         """
 
-        def __init__(self):
+        def __init__(self) -> None:
             self._options = {}
 
         def _remove_config(self, key: str) -> "Session.SessionBuilder":
@@ -205,6 +209,8 @@ class Session:
             new_session = Session(
                 ServerConnection({}, conn) if conn else ServerConnection(self._options)
             )
+            if "password" in self._options:
+                self._options["password"] = None
             _add_session(new_session)
             return new_session
 
@@ -215,7 +221,7 @@ class Session:
     #: and create a :class:`Session` object.
     builder: SessionBuilder = SessionBuilder()
 
-    def __init__(self, conn: ServerConnection):
+    def __init__(self, conn: ServerConnection) -> None:
         if len(_active_sessions) >= 1 and is_in_stored_procedure():
             raise SnowparkClientExceptionMessages.DONT_CREATE_SESSION_IN_SP()
         self._conn = conn
@@ -233,16 +239,16 @@ class Session:
         self._session_stage = random_name_for_temp_object(TempObjectType.STAGE)
         self._stage_created = False
         self._udf_registration = UDFRegistration(self)
+        self._udtf_registration = UDTFRegistration(self)
         self._sp_registration = StoredProcedureRegistration(self)
         self._plan_builder = SnowflakePlanBuilder(self)
-
         self._last_action_id = 0
         self._last_canceled_id = 0
 
         self._file = FileOperation(self)
 
         self._analyzer = Analyzer(self)
-        logger.info("Snowpark Session information: %s", self._session_info)
+        _logger.info("Snowpark Session information: %s", self._session_info)
 
     def __enter__(self):
         return self
@@ -260,19 +266,19 @@ class Session:
             raise SnowparkClientExceptionMessages.DONT_CLOSE_SESSION_IN_SP()
         try:
             if self._conn.is_closed():
-                logger.debug(
+                _logger.debug(
                     "No-op because session %s had been previously closed.",
                     self._session_id,
                 )
             else:
-                logger.info(f"Closing session: %s", self._session_id)
+                _logger.info("Closing session: %s", self._session_id)
                 self.cancel_all()
         except Exception as ex:
             raise SnowparkClientExceptionMessages.SERVER_FAILED_CLOSE_SESSION(str(ex))
         finally:
             try:
                 self._conn.close()
-                logger.info(f"Closed session: %s", self._session_id)
+                _logger.info("Closed session: %s", self._session_id)
             finally:
                 _remove_session(self)
 
@@ -281,7 +287,7 @@ class Session:
         Cancel all action methods that are running currently.
         This does not affect any action methods called in the future.
         """
-        logger.info("Canceling all running queries")
+        _logger.info("Canceling all running queries")
         self._last_canceled_id = self._last_action_id
         self._conn.run_query(f"select system$cancel_all_queries({self._session_id})")
 
@@ -470,7 +476,7 @@ class Session:
                 )
                 filename_with_prefix = f"{prefix}/{filename}"
                 if filename_with_prefix in stage_file_list:
-                    logger.debug(
+                    _logger.debug(
                         f"{filename} exists on {normalized_stage_location}, skipped"
                     )
                 else:
@@ -732,6 +738,12 @@ class Session:
                             "on the server but not on your local environment.",
                             package_name,
                         )
+                    except Exception as ex:
+                        logging.warning(
+                            "Failed to get the local distribution of package %s: %s",
+                            package_name,
+                            ex,
+                        )
 
             if package_name in result_dict:
                 if result_dict[package_name] != package:
@@ -787,7 +799,7 @@ class Session:
 
     def table(self, name: Union[str, Iterable[str]]) -> Table:
         """
-        Returns a DataFrame that points the specified table.
+        Returns a Table that points the specified table.
 
         Args:
             name: A string or list of strings that specify the table name or
@@ -812,7 +824,7 @@ class Session:
 
     def table_function(
         self,
-        func_name: Union[str, List[str]],
+        func_name: Union[str, List[str], TableFunctionCall],
         *func_arguments: ColumnOrName,
         **func_named_arguments: ColumnOrName,
     ) -> DataFrame:
@@ -820,12 +832,34 @@ class Session:
 
         References: `Snowflake SQL functions <https://docs.snowflake.com/en/sql-reference/functions-table.html>`_.
 
-        Example::
+        Example 1
+            Query a table function by function name:
 
             >>> from snowflake.snowpark.functions import lit
             >>> session.table_function("split_to_table", lit("split words to table"), lit(" ")).collect()
             [Row(SEQ=1, INDEX=1, VALUE='split'), Row(SEQ=1, INDEX=2, VALUE='words'), Row(SEQ=1, INDEX=3, VALUE='to'), Row(SEQ=1, INDEX=4, VALUE='table')]
 
+        Example 2
+            Define a table function variable and query it:
+
+            >>> from snowflake.snowpark.functions import table_function, lit
+            >>> split_to_table = table_function("split_to_table")
+            >>> session.table_function(split_to_table(lit("split words to table"), lit(" "))).collect()
+            [Row(SEQ=1, INDEX=1, VALUE='split'), Row(SEQ=1, INDEX=2, VALUE='words'), Row(SEQ=1, INDEX=3, VALUE='to'), Row(SEQ=1, INDEX=4, VALUE='table')]
+
+        Example 3
+            If you want to call a UDTF right after it's registered, the returned ``UserDefinedTableFunction`` is callable:
+
+            >>> from snowflake.snowpark.types import IntegerType, StructField, StructType
+            >>> from snowflake.snowpark.functions import udtf, lit
+            >>> class GeneratorUDTF:
+            ...     def process(self, n):
+            ...         for i in range(n):
+            ...             yield (i, )
+            >>> generator_udtf = udtf(GeneratorUDTF, output_schema=StructType([StructField("number", IntegerType())]), input_types=[IntegerType()])
+            >>> session.table_function(generator_udtf(lit(3))).collect()
+            [Row(NUMBER=0), Row(NUMBER=1), Row(NUMBER=2)]
+
         Args:
             func_name: The SQL function name.
             func_arguments: The positional arguments for the SQL function.
@@ -837,7 +871,7 @@ class Session:
         See Also:
             - :meth:`DataFrame.join_table_function`, which lateral joins an existing :class:`DataFrame` and a SQL function.
         """
-        func_expr = create_table_function_expression(
+        func_expr = _create_table_function_expression(
             func_name, *func_arguments, **func_named_arguments
         )
         return DataFrame(
@@ -896,7 +930,6 @@ class Session:
             self._stage_created = True
         return f"{STAGE_PREFIX}{qualified_stage_name}"
 
-    # TODO make the table input consistent with session.table
     def write_pandas(
         self,
         df: "pandas.DataFrame",
@@ -1069,8 +1102,8 @@ class Session:
             table_name = escape_quotes(
                 random_name_for_temp_object(TempObjectType.TABLE)
             )
-            sf_database = self.get_current_database(unquoted=True)
-            sf_schema = self.get_current_schema(unquoted=True)
+            sf_database = self._conn._get_current_parameter("database", quoted=False)
+            sf_schema = self._conn._get_current_parameter("schema", quoted=False)
 
             return self.write_pandas(
                 data,
@@ -1136,7 +1169,7 @@ class Session:
             names = [f.name for f in new_schema.fields]
         rows = [convert_row_to_list(row, names) for row in data]
 
-        # get spark attributes and data types
+        # get attributes and data types
         attrs, data_types = [], []
         for field in new_schema.fields:
             sf_type = (
@@ -1261,25 +1294,19 @@ class Session:
         range_plan = Range(0, start, step) if end is None else Range(start, end, step)
         return DataFrame(self, range_plan)
 
-    def get_current_database(self, unquoted: bool = False) -> Optional[str]:
+    def get_current_database(self) -> Optional[str]:
         """
         Returns the name of the current database for the Python connector session attached
         to this session. See the example in :meth:`table`.
-
-        Args:
-            unquoted: The result will be unquoted if it is true.
         """
-        return self._conn._get_current_parameter("database", unquoted=unquoted)
+        return self._conn._get_current_parameter("database")
 
-    def get_current_schema(self, unquoted: bool = False) -> Optional[str]:
+    def get_current_schema(self) -> Optional[str]:
         """
         Returns the name of the current schema for the Python connector session attached
         to this session. See the example in :meth:`table`.
-
-        Args:
-            unquoted: The result will be unquoted if it is true.
         """
-        return self._conn._get_current_parameter("schema", unquoted=unquoted)
+        return self._conn._get_current_parameter("schema")
 
     def get_fully_qualified_current_schema(self) -> str:
         """Returns the fully qualified name of the current schema for the session."""
@@ -1287,29 +1314,22 @@ class Session:
         schema = self.get_current_schema()
         if database is None or schema is None:
             missing_item = "DATABASE" if not database else "SCHEMA"
-            # TODO: SNOW-372569 Use ErrorMessage
             raise SnowparkClientExceptionMessages.SERVER_CANNOT_FIND_CURRENT_DB_OR_SCHEMA(
                 missing_item, missing_item, missing_item
             )
         return database + "." + schema
 
-    def get_current_warehouse(self, unquoted: bool = False) -> Optional[str]:
+    def get_current_warehouse(self) -> Optional[str]:
         """
         Returns the name of the warehouse in use for the current session.
-
-        Args:
-            unquoted: The result will be unquoted if it is true.
         """
-        return self._conn._get_current_parameter("warehouse", unquoted=unquoted)
+        return self._conn._get_current_parameter("warehouse")
 
-    def get_current_role(self, unquoted: bool = False) -> Optional[str]:
+    def get_current_role(self) -> Optional[str]:
         """
         Returns the name of the primary role in use for the current session.
-
-        Args:
-            unquoted: The result will be unquoted if it is true.
         """
-        return self._conn._get_current_parameter("role", unquoted=unquoted)
+        return self._conn._get_current_parameter("role")
 
     def use_database(self, database: str) -> None:
         """Specifies the active/current database for the session.
@@ -1400,6 +1420,14 @@ class Session:
         """
         return self._udf_registration
 
+    @property
+    def udtf(self) -> UDTFRegistration:
+        """
+        Returns a :class:`udf.UDTFRegistration` object that you can use to register UDFs.
+        See details of how to use this object in :class:`udf.UDFRegistration`.
+        """
+        return self._udtf_registration
+
     @property
     def sproc(self) -> StoredProcedureRegistration:
         """
@@ -1440,6 +1468,11 @@ class Session:
             sql_args.append(to_sql(arg, infer_type(arg)))
         return self.sql(f"CALL {sproc_name}({', '.join(sql_args)})").collect()[0][0]
 
+    @deprecate(
+        deprecate_version="0.7.0",
+        extra_warning_text="`Session.flatten()` is deprecated. Use `Session.table_function()` instead.",
+        extra_doc_string="This method is deprecated. Use :meth:`table_function` instead.",
+    )
     def flatten(
         self,
         input: ColumnOrName,
@@ -1512,7 +1545,7 @@ class Session:
         return DataFrame(
             self,
             TableFunctionRelation(
-                FlattenFunction(input.expression, path, outer, recursive, mode)
+                FlattenFunction(input._expression, path, outer, recursive, mode)
             ),
         )
 
@@ -1538,7 +1571,7 @@ class Session:
             return self._run_query(f"explain using text {query}")[0][0]
         # return None for queries which can't be explained
         except ProgrammingError:
-            logger.warning("query '%s' cannot be explained")
+            _logger.warning("query '%s' cannot be explained")
             return None
 
     createDataFrame = create_dataframe
