@@ -3,11 +3,14 @@
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
 """User-defined functions (UDFs) in Snowpark."""
+import sys
 from types import ModuleType
 from typing import Callable, Iterable, List, Optional, Tuple, Union
 
 import snowflake.snowpark
+from snowflake.connector import ProgrammingError
 from snowflake.snowpark._internal.analyzer.expression import Expression, SnowflakeUDF
+from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
 from snowflake.snowpark._internal.type_utils import ColumnOrName, convert_sp_to_sf_type
 from snowflake.snowpark._internal.udf_utils import (
     UDFColumn,
@@ -49,7 +52,7 @@ class UserDefinedFunction:
         input_types: List[DataType],
         name: str,
         is_return_nullable: bool = False,
-    ):
+    ) -> None:
         #: The Python function or a tuple containing the Python file path and the function name.
         self.func: Union[Callable, Tuple[str, str]] = func
         #: The UDF name.
@@ -66,9 +69,9 @@ class UserDefinedFunction:
         exprs = []
         for c in parse_positional_args_to_list(*cols):
             if isinstance(c, Column):
-                exprs.append(c.expression)
+                exprs.append(c._expression)
             elif isinstance(c, str):
-                exprs.append(Column(c).expression)
+                exprs.append(Column(c)._expression)
             else:
                 raise TypeError(
                     f"The input of UDF {self.name} must be Column, column name, or a list of them"
@@ -413,7 +416,7 @@ class UDFRegistration:
         - :meth:`~snowflake.snowpark.Session.add_packages`
     """
 
-    def __init__(self, session: "snowflake.snowpark.session.Session"):
+    def __init__(self, session: "snowflake.snowpark.session.Session") -> None:
         self._session = session
 
     def describe(
@@ -480,17 +483,19 @@ class UDFRegistration:
                 strings to represent a file path and an import path (similar to the ``import_path``
                 argument in :meth:`~snowflake.snowpark.Session.add_import`). These UDF-level imports
                 will override the session-level imports added by
-                :meth:`~snowflake.snowpark.Session.add_import`.
+                :meth:`~snowflake.snowpark.Session.add_import`. Note that an empty list means
+                no import for this UDF, and ``None`` or not specifying this parameter means using
+                session-level imports.
             packages: A list of packages that only apply to this UDF. These UDF-level packages
                 will override the session-level packages added by
                 :meth:`~snowflake.snowpark.Session.add_packages` and
-                :meth:`~snowflake.snowpark.Session.add_requirements`.
+                :meth:`~snowflake.snowpark.Session.add_requirements`. Note that an empty list means
+                no package for this UDF, and ``None`` or not specifying this parameter means using
+                session-level packages.
             replace: Whether to replace a UDF that already was registered. The default is ``False``.
                 If it is ``False``, attempting to register a UDF with a name that already exists
                 results in a ``ProgrammingError`` exception being thrown. If it is ``True``,
                 an existing UDF with the same name is overwritten.
-            session: Use this session to register the UDF. If it's not specified, the session that you created before calling this function will be used.
-                You need to specify this parameter if you have created multiple sessions before calling this method.
             parallel: The number of threads to use for uploading UDF files with the
                 `PUT <https://docs.snowflake.com/en/sql-reference/sql/put.html#put>`_
                 command. The default value is 4 and supported values are from 1 to 99.
@@ -586,17 +591,19 @@ class UDFRegistration:
                 strings to represent a file path and an import path (similar to the ``import_path``
                 argument in :meth:`~snowflake.snowpark.Session.add_import`). These UDF-level imports
                 will override the session-level imports added by
-                :meth:`~snowflake.snowpark.Session.add_import`.
+                :meth:`~snowflake.snowpark.Session.add_import`. Note that an empty list means
+                no import for this UDF, and ``None`` or not specifying this parameter means using
+                session-level imports.
             packages: A list of packages that only apply to this UDF. These UDF-level packages
                 will override the session-level packages added by
                 :meth:`~snowflake.snowpark.Session.add_packages` and
-                :meth:`~snowflake.snowpark.Session.add_requirements`.
+                :meth:`~snowflake.snowpark.Session.add_requirements`. Note that an empty list means
+                no package for this UDF, and ``None`` or not specifying this parameter means using
+                session-level packages.
             replace: Whether to replace a UDF that already was registered. The default is ``False``.
                 If it is ``False``, attempting to register a UDF with a name that already exists
                 results in a ``ProgrammingError`` exception being thrown. If it is ``True``,
                 an existing UDF with the same name is overwritten.
-            session: Use this session to register the UDF. If it's not specified, the session that you created before calling this function will be used.
-                You need to specify this parameter if you have created multiple sessions before calling this method.
             parallel: The number of threads to use for uploading UDF files with the
                 `PUT <https://docs.snowflake.com/en/sql-reference/sql/put.html#put>`_
                 command. The default value is 4 and supported values are from 1 to 99.
@@ -690,6 +697,7 @@ class UDFRegistration:
             max_batch_size,
         )
 
+        raised = False
         try:
             create_python_udf_or_sp(
                 session=self._session,
@@ -704,14 +712,24 @@ class UDFRegistration:
                 replace=replace,
                 inline_python_code=code,
             )
-        # an exception might happen during registering a stored procedure
+        # an exception might happen during registering a udf
         # (e.g., a dependency might not be found on the stage),
-        # then for a permanent stored procedure, we should delete the uploaded
+        # then for a permanent udf, we should delete the uploaded
         # python file and raise the exception
-        except BaseException:
-            cleanup_failed_permanent_registration(
-                self._session, upload_file_stage_location, stage_location
+        except ProgrammingError as pe:
+            raised = True
+            tb = sys.exc_info()[2]
+            ne = SnowparkClientExceptionMessages.SQL_EXCEPTION_FROM_PROGRAMMING_ERROR(
+                pe
             )
+            raise ne.with_traceback(tb) from None
+        except BaseException:
+            raised = True
             raise
+        finally:
+            if raised:
+                cleanup_failed_permanent_registration(
+                    self._session, upload_file_stage_location, stage_location
+                )
 
         return UserDefinedFunction(func, return_type, input_types, udf_name)
